//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/SoftParticle/FuzzySphere.h
//! @brief     Defines and implements class FuzzySphere.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_SOFTPARTICLE_FUZZYSPHERE_H
#define BORNAGAIN_SAMPLE_SOFTPARTICLE_FUZZYSPHERE_H

#include "Sample/Particle/IFormFactor.h"
#include <memory>

//! A sphere with gaussian radius distribution.
//! @ingroup softParticle

class FuzzySphere : public IFormFactor {
public:
    FuzzySphere(std::vector<double> P);
    FuzzySphere(double mean, double sigma);

    FuzzySphere* clone() const override { return new FuzzySphere(m_radius, m_sigma); }
    std::string className() const final { return "FuzzySphere"; }
    // const auto tooltip = "class_tooltip";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Radius", "nm", "para_tooltip", 0, +INF, 0},
                {"Fuzziness", "nm", "para_tooltip", 0, +INF, 0}};
    }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius;
    const double& m_sigma;
};

#endif // BORNAGAIN_SAMPLE_SOFTPARTICLE_FUZZYSPHERE_H
